==> item-descriptions-2.5.3%2B1.21.10-fabric-sources.jar: cc/cassian/item_descriptions/client/mixin/MatrixEnchantmentScreenMixin.java <==
package cc.cassian.item_descriptions.client.mixin;
import cc.cassian.item_descriptions.client.DescriptionKey;
import cc.cassian.item_descriptions.client.ModClient;
import cc.cassian.item_descriptions.client.helpers.ModHelpers;
import cc.cassian.item_descriptions.client.helpers.ModStyle;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Pseudo;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import java.util.List;
import java.util.Optional;
import net.minecraft.class_486;

@Pseudo
//? if (=1.21.1 || =1.20.1) && neoforge {
/*@Mixin(MatrixEnchantingScreen.class)
*///?} else {
@Mixin(class_486.class)
//?}
public class MatrixEnchantmentScreenMixin {
    //? if (=1.21.1 || =1.20.1) && neoforge {
    /*@Shadow protected EnchantmentMatrix.Piece hoveredPiece;

    @WrapOperation(method = "render", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;renderComponentTooltip(Lnet/minecraft/client/gui/Font;Ljava/util/List;II)V"))
    private void addEnchantmentDescriptions(GuiGraphics instance, Font textRenderer, List<Component> components, int mouseX, int mouseY, Operation<Void> original) {
        //? if >=1.21 {
        Holder<Enchantment> enchant
        //?} else {
        /^Enchantment enchant
         ^///?}
        = this.hoveredPiece.enchant;
        if (ModHelpers.showEnchantmentDescriptions() && ModClient.CONFIG.enchantmentDescriptions.enchantingTable.value()) {
            Component name =
            //? if >=1.21 {
             Enchantment.getFullname(enchant, 1);
            //?} else {
            /^enchant.getFullname(1);
            ^///?}
            if (name.getContents() instanceof TranslatableContents content) {
                List<Component> tooltip = ModHelpers.createTooltip(name, new DescriptionKey(content.getKey()).toText().setStyle(ModStyle.ENCHANTMENT_DESCRIPTIONS), true);
                components.addAll(tooltip);
            }
        }
        original.call(instance, textRenderer, components, mouseX, mouseY);
    }
    *///?}
}

==> item-descriptions-2.5.4%2B1.21.10-fabric-sources.jar: cc/cassian/item_descriptions/client/mixin/MatrixEnchantmentScreenMixin.java <==
package cc.cassian.item_descriptions.client.mixin;
import cc.cassian.item_descriptions.client.DescriptionKey;
import cc.cassian.item_descriptions.client.ModClient;
import cc.cassian.item_descriptions.client.helpers.ModHelpers;
import cc.cassian.item_descriptions.client.helpers.ModStyle;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Pseudo;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import java.util.List;
import java.util.Optional;
import net.minecraft.class_486;

@Pseudo
//? if (=1.21.1 || =1.20.1) && neoforge {
/*@Mixin(MatrixEnchantingScreen.class)
*///?} else {
@Mixin(class_486.class)
//?}
public class MatrixEnchantmentScreenMixin {
    //? if (=1.21.1 || =1.20.1) && neoforge {
    /*@Shadow protected EnchantmentMatrix.Piece hoveredPiece;

    @WrapOperation(method = "render", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;renderComponentTooltip(Lnet/minecraft/client/gui/Font;Ljava/util/List;II)V"))
    private void addEnchantmentDescriptions(GuiGraphics instance, Font textRenderer, List<Component> components, int mouseX, int mouseY, Operation<Void> original) {
        //? if >=1.21 {
        /^Holder<Enchantment> enchant
        ^///?} else {
        Enchantment enchant
         //?}
        = this.hoveredPiece.enchant;
        if (ModHelpers.showEnchantmentDescriptions() && ModClient.CONFIG.enchantmentDescriptions.enchantingTable.value()) {
            Component name =
            //? if >=1.21 {
             /^Enchantment.getFullname(enchant, 1);
            ^///?} else {
            enchant.getFullname(1);
            //?}
            if (name.getContents() instanceof TranslatableContents content) {
                List<Component> tooltip = ModHelpers.createTooltip(name, new DescriptionKey(content.getKey()).toText().setStyle(ModStyle.ENCHANTMENT_DESCRIPTIONS), true);
                components.addAll(tooltip);
            }
        }
        original.call(instance, textRenderer, components, mouseX, mouseY);
    }
    *///?}
}
